﻿using Sharing.Province.Dtos;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.Dtos.XieTong.Knowledge;
using Sharing.Province.Dtos.XieTong.Send;

namespace Sharing.Province;

/// <summary>
/// 默认策略（保持原数据策略）
/// </summary>
public class DefaultPusher : IProvincePusher
{
    private readonly HuiJuClient _huiJuClient;
    private readonly XieTongClient _xieTongClient;

    /// <summary>
    /// 
    /// </summary>
    /// <param name="huiJuClient"></param>
    /// <param name="xieTongClient"></param>
    public DefaultPusher(HuiJuClient huiJuClient, XieTongClient xieTongClient)
    {
        _huiJuClient = huiJuClient;
        _xieTongClient = xieTongClient;
    }

    #region 协同-第一批次
    /// <summary>
    /// 服务工单交办处理
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetCaseResultReceiveAsync(GetCaseResultReceiveRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetCaseResultReceiveRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单交办处理过程
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetCaseProcessReceiveAsync(GetCaseProcessReceiveRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetCaseProcessReceiveRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单交办评价
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetVisitInfoReceiveAsync(GetVisitInfoReceiveRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetVisitInfoReceiveRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 退回申请
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetCaseBackApplyAsync(GetCaseBackApplyRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<GetCaseBackApplyRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单申请延时
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushDelayCaseInfoSendAsync(DelayCaseInfoSendRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<DelayCaseInfoSendRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单督办过程
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSendSuperviseProcessInfoAsync(SendSuperviseProcessInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<SendSuperviseProcessInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单督办结果
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSendSuperviseResultInfoAsync(SendSuperviseResultInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<SendSuperviseResultInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 工单发起甄别接
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushScreenCaseInfoSendAsync(ScreenCaseInfoSendRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<ScreenCaseInfoSendRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 政民互动提交公开
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushZMHDCaseInfoPublicAsync(ZMHDCaseInfoPublicRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<ZMHDCaseInfoPublicRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    #endregion

    #region 汇聚-第二批次
    /// <summary>
    /// 服务工单受理
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushOrderCreatedAsync(SubmitCaseInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单处理结果
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSubmitCaseResultAsync(SubmitCaseResultRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseResultRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单处理过程
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSubmitCaseProcessAsync(SubmitCaseProcessRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseProcessRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单回访评价
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSubmitVisitInfoAsync(SubmitVisitInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitVisitInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 电话记录
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSubmitCaseRecordAsync(SubmitCaseRecordRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseRecordRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 统计数据
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSubmitCaseTotalAsync(SubmitCaseTotalRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseTotalRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单拓展信息
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSubmitCaseExtendsAsync(SubmitCaseExtendsRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SubmitCaseExtendsRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }
    #endregion
    
    #region 协同-第三批次
    /// <summary>
    /// 服务工单上报
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSendCaseInfoAsync(SendCaseInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<SendCaseInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 上报补充诉求
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSupplyCaseInfoSendAsync(SupplyCaseInfoSendRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<SupplyCaseInfoSendRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单撤单
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushRevokeCaseInfoAsync(SendRevokeCaseInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<SendRevokeCaseInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 服务工单催单
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSendRemindCaseInfoAsync(SendRemindCaseInfoRequest request, CancellationToken cancellationToken)
    {
        var response = await _xieTongClient.RequestAsync<SendRemindCaseInfoRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }
    #endregion

    #region 协同-第四批次
    /// <summary>
    /// 知识库上报
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetKnowledgeInfoSendAsync(GetKnowledgeInfoSendRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<GetKnowledgeInfoSendRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 知识库变更
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetKnowledgeInfoUpdateAsync(GetKnowledgeInfoUpdateRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<GetKnowledgeInfoUpdateRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 知识库下架
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushGetKnowledgeInfoAbandonAsync(GetKnowledgeInfoAbandonRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<GetKnowledgeInfoAbandonRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    /// <summary>
    /// 实时服务上报
    /// </summary>
    /// <param name="request"></param>
    /// <param name="cancellationToken"></param>
    /// <returns></returns>
    public async Task<BaseProvinceResponse> PushSendRealTimeStatusAsync(SendRealTimeStatusRequest request, CancellationToken cancellationToken)
    {
        var response = await _huiJuClient.RequestAsync<SendRealTimeStatusRequest, ProvinceResponse>(request, cancellationToken);
        return response?.ReturnInfo;
    }

    #endregion
}
