﻿using Microsoft.AspNetCore.Http;
using System.Text.Json.Serialization;

namespace Sharing.Province.Dtos.HuiJu.Send;

/// <summary>
/// 服务工单受理
/// </summary>
public class SubmitCaseInfoRequest : ProvinceRequest<SubmitCaseInfoData>
{
    //业务汇聚-服务工单受理接口

    public override string GetRequestUrl() => "submit_case_info";

    public override string GetHttpMethod() => HttpMethods.Post;
}

/// <summary>
/// 服务工单受理
/// </summary>
public class SubmitCaseInfoData
{
    [JsonPropertyName("jsonList")]
    public IReadOnlyList<CaseInfo> CaseInfos { get; set; }
}

/// <summary>
/// 
/// </summary>
public class CaseInfo : BaseModel
{
    /// <summary>
    /// 服务工单标题
    /// </summary>
    [JsonPropertyName("CASE_TITLE")]
    public string CaseTitle { get; set; }

    /// <summary>
    /// 服务代表姓名
    /// </summary>
    [JsonPropertyName("CASE_REGISTER")]
    public string CaseRegister { get; set; }

    /// <summary>
    /// 服务代表工号
    /// </summary>
    [JsonPropertyName("CASE_REGISTERNO")]
    public string CaseRegisterNo { get; set; }

    /// <summary>
    /// 登记时间
    /// </summary>
    [JsonPropertyName("CASE_DATE")]
    public DateTime CaseDate { get; set; }

    /// <summary>
    /// 诉求渠道
    /// </summary>
    [JsonPropertyName("CASE_SOURCE")]
    public DateTime CaseSource { get; set; }

    /// <summary>
    /// 联系电话
    /// </summary>
    [JsonPropertyName("PHONE_NUMBER")]
    public string PhoneNumber { get; set; }

    /// <summary>
    /// 服务对象名称
    /// </summary>
    [JsonPropertyName("APPLICANT_NAME")]
    public string AppLicantName { get; set; }

    /// <summary>
    /// 服务对象性别
    /// </summary>
    [JsonPropertyName("APPLICANT_SEX")]
    public string AppLicantSex { get; set; }

    /// <summary>
    /// 服务对象年龄
    /// </summary>
    [JsonPropertyName("APPLICANT_AGE")]
    public string AppLicantAge { get; set; }

    /// <summary>
    /// 证件号码
    /// </summary>
    [JsonPropertyName("APPLICANT_ID")]
    public string AppLicantId { get; set; }

    /// <summary>
    /// 证件类型
    /// </summary>
    [JsonPropertyName("CERTIFICATE_TYPE")]
    public string CertifiCateType { get; set; }

    /// <summary>
    /// 诉求类型
    /// </summary>
    [JsonPropertyName("CASE_TYPE")]
    public string CaseType { get; set; }

    /// <summary>
    /// 诉求归口
    /// </summary>
    [JsonPropertyName("CASE_ACCORD")]
    public string CaseAccord { get; set; }

    /// <summary>
    /// 诉求内容
    /// </summary>
    [JsonPropertyName("CASE_CONTENT")]
    public string CaseContent { get; set; }

    /// <summary>
    /// 处理方式
    /// </summary>
    [JsonPropertyName("CASE_PROCESS_TYPE")]
    public string CaseProcessType { get; set; }

    /// <summary>
    /// 是否公开
    /// </summary>
    [JsonPropertyName("CASE_ISPUBLIC")]
    public string CaseIsPublic { get; set; }

    /// <summary>
    /// 是否保密
    /// </summary>
    [JsonPropertyName("CASE_ISSECRECT")]
    public string CaseIsSecrect { get; set; }

    /// <summary>
    /// 是否回访-工单是否需要回访
    /// </summary>
    [JsonPropertyName("CASE_ISVISIT")]
    public string CaseIsVisit { get; set; }

    /// <summary>
    /// 是否有效受理
    /// </summary>
    [JsonPropertyName("CASE_VALID")]
    public string CaseValid { get; set; }

    /// <summary>
    /// 紧急程度
    /// </summary>
    [JsonPropertyName("CASE_ISURGENT")]
    public string CaseIsUrgent { get; set; }

    /// <summary>
    /// 应签收时限
    /// </summary>
    [JsonPropertyName("TSIGNTIME_BF")]
    public DateTime? TSigntTmeBf { get; set; }

    /// <summary>
    /// 应办结时限
    /// </summary>
    [JsonPropertyName("TFDBACKTIME_BF")]
    public DateTime? TfdBackTimeBf { get; set; }

    /// <summary>
    /// 应退回时限
    /// </summary>
    [JsonPropertyName("TBACKTIME_BF")]
    public DateTime? TBackTimeBf { get; set; }

    /// <summary>
    /// 关联服务工单
    /// </summary>
    [JsonPropertyName("RELATE_SERIAL")]
    public string? RelateSerial { get; set; }

    /// <summary>
    /// 经纬度
    /// </summary>
    [JsonPropertyName("CASE_LNGLAT")]
    public string CaseLngLat { get; set; }

    /// <summary>
    /// 诉求情感
    /// </summary>
    [JsonPropertyName("CASE_EMOTION")]
    public string CaseEmotion { get; set; }

    /// <summary>
    /// 诉求详细地址
    /// </summary>
    [JsonPropertyName("CASE_ADDRESS")]
    public string CaseAddress { get; set; }

    /// <summary>
    /// 事发时间
    /// </summary>
    [JsonPropertyName("EVENT_DATE")]
    public DateTime? EventDate { get; set; }

    /// <summary>
    /// 诉求目的
    /// </summary>
    [JsonPropertyName("CASE_GOAL")]
    public string CaseGoal { get; set; }

    /// <summary>
    /// 主题工单类型
    /// </summary>
    [JsonPropertyName("THEME_SERIAL")]
    public string ThemeSerial { get; set; }

    /// <summary>
    /// 建议类型
    /// </summary>
    [JsonPropertyName("ADVISE_TYPE")]
    public string AdviseType { get; set; }

    /// <summary>
    /// 建议部门
    /// </summary>
    [JsonPropertyName("ADVISE_DEPT")]
    public string AdviseDept { get; set; }

    /// <summary>
    /// 投诉类型
    /// </summary>
    [JsonPropertyName("COMPLAIN_TYPE")]
    public string ComplainType { get; set; }

    /// <summary>
    /// 投诉部门
    /// </summary>
    [JsonPropertyName("COMPLAIN_DEPT")]
    public string ComplainDept { get; set; }

    /// <summary>
    /// 推送类型
    /// </summary>
    [JsonPropertyName("PUSH_TYPE")]
    public string PushType { get; set; }
}
