﻿using Microsoft.AspNetCore.Http;
using System.Text.Json.Serialization;

namespace Sharing.Province.Dtos.HuiJu.Send
{
    /// <summary>
    /// 服务工单处理过程
    /// </summary>
    public class SubmitCaseProcessRequest : ProvinceRequest<SubmitCaseProcessData>
    {
        //服务工单处理结果

        public override string GetRequestUrl() => "submit_case_process";

        public override string GetHttpMethod() => HttpMethods.Post;
    }

    /// <summary>
    /// 服务工单处理过程
    /// </summary>
    public class SubmitCaseProcessData
    {
        [JsonPropertyName("jsonList")]
        public IReadOnlyList<CaseProcess> CaseProcesss { get; set; }
    }

    /// <summary>
    /// 
    /// </summary>
    public class CaseProcess : BaseModel
    {
        /// <summary>
        /// 处理部门
        /// </summary>
        [JsonPropertyName("DEPT_NAME")]
        public string DeptName { get; set; }

        /// <summary>
        /// 环节名称
        /// </summary>
        [JsonPropertyName("TACHE_NAME")]
        public string TacheName { get; set; }

        /// <summary>
        /// 处理时间
        /// </summary>
        [JsonPropertyName("PROCESS_TIME")]
        public DateTime? ProcessTime { get; set; }

        /// <summary>
        /// 处理人员
        /// </summary>
        [JsonPropertyName("PROCESS_NAME")]
        public string ProcessName { get; set; }

        /// <summary>
        /// 处理意见
        /// </summary>
        [JsonPropertyName("PROCESS_NOTE")]
        public string ProcessNote { get; set; }

        /// <summary>
        /// 办理部门所在区、市、县行政区划代码
        /// </summary>
        [JsonPropertyName("END_AREACODE")]
        public string EndAreaCode { get; set; }

        /// <summary>
        /// 办理部门所在区、市、县行政区划名称
        /// </summary>
        [JsonPropertyName("END_AREANAME")]
        public string EndAreaName { get; set; }

        /// <summary>
        /// 过程记录唯一标识
        /// </summary>
        [JsonPropertyName("case_id")]
        public string CaseId { get; set; }
    }
}
