﻿using Microsoft.AspNetCore.Http;
using System.Text.Json.Serialization;

namespace Sharing.Province.Dtos.HuiJu.Send
{
    /// <summary>
    /// 服务工单处理结果
    /// </summary>
    public class SubmitCaseResultRequest : ProvinceRequest<SubmitCaseResultData>
    {
        //服务工单处理结果

        public override string GetRequestUrl() => "submit_case_result";

        public override string GetHttpMethod() => HttpMethods.Post;
    }

    /// <summary>
    /// 服务工单处理结果
    /// </summary>
    public class SubmitCaseResultData
    {
        [JsonPropertyName("jsonList")]
        public IReadOnlyList<CaseResult> CaseResults { get; set; }
    }

    /// <summary>
    /// 
    /// </summary>
    public class CaseResult : BaseModel
    {
        /// <summary>
        /// 答复单位
        /// </summary>
        [JsonPropertyName("DEPT_NAME")]
        public string DeptName { get; set; }

        /// <summary>
        /// 答复时间
        /// </summary>
        [JsonPropertyName("FINISH_TIME")]
        public DateTime? FinishTime { get; set; }

        /// <summary>
        /// 答复人员
        /// </summary>
        [JsonPropertyName("FINISH_NAME")]
        public string FinishName { get; set; }

        /// <summary>
        /// 办理情况
        /// </summary>
        [JsonPropertyName("FINISH_NOTE")]
        public string FinishNote { get; set; }

        /// <summary>
        /// 办理单位
        /// </summary>
        [JsonPropertyName("END_DEPT")]
        public string EndDept { get; set; }

        /// <summary>
        /// 办理人员
        /// </summary>
        [JsonPropertyName("END_NAME")]
        public string EndName { get; set; }

        /// <summary>
        /// 联系时间
        /// </summary>
        [JsonPropertyName("CONCACT_TIME")]
        public DateTime? ConcactTime { get; set; }

        /// <summary>
        /// 联系方式
        /// </summary>
        [JsonPropertyName("CONCACT_TYPE")]
        public string ConcactType { get; set; }

        /// <summary>
        /// 办理操作
        /// </summary>
        [JsonPropertyName("FINISH_TYPE")]
        public string FinishType { get; set; }

        /// <summary>
        /// 办理时长
        /// </summary>
        [JsonPropertyName("HANDLETIME_LONG")]
        public int HandleTimeLong { get; set; }

        /// <summary>
        /// 应签收时间
        /// </summary>
        [JsonPropertyName("SIGN_TIME_BF")]
        public DateTime? SignTimeBf { get; set; }

        /// <summary>
        /// 签收时间
        /// </summary>
        [JsonPropertyName("SIGN_TIME")]
        public DateTime? SignTime { get; set; }

        /// <summary>
        /// 应反馈时间
        /// </summary>
        [JsonPropertyName("FDBACKTIME_BF")]
        public DateTime? FdBackTime_Bf { get; set; }

        /// <summary>
        /// 反馈时间
        /// </summary>
        [JsonPropertyName("FDBACKTIME")]
        public DateTime? FdBackTime { get; set; }

        /// <summary>
        /// 交办时间
        /// </summary>
        [JsonPropertyName("SEND_TIME")]
        public DateTime? SendTime { get; set; }

        /// <summary>
        /// 反馈意见
        /// </summary>
        [JsonPropertyName("FDBACK")]
        public string FdBack { get; set; }

        /// <summary>
        /// 办结单位所在区县区域代码
        /// </summary>
        [JsonPropertyName("END_AREACODE")]
        public string EndAreaCode { get; set; }

        /// <summary>
        /// 办结单位所在区县名称
        /// </summary>
        [JsonPropertyName("END_AREANAME")]
        public string EndAreaName { get; set; }

        /// <summary>
        /// 工单办理过程中交办单位
        /// </summary>
        [JsonPropertyName("BEIZHU")]
        public string BeiZhu { get; set; }
    }
}
