﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 服务工单受理
    /// </summary>
    public class OrderCreatedHandler : INotificationHandler<OrderCreatedNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISubmitCaseInfoRepository _submitCaseInfoRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        public OrderCreatedHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper, ISubmitCaseInfoRepository submitCaseInfoRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseInfoRepository = submitCaseInfoRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(OrderCreatedNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<CaseInfo>(order);

            var data = new SubmitCaseInfoData
            {
                CaseInfos = new List<CaseInfo>
                {
                    dataReceive
                }
            };
            var request = new SubmitCaseInfoRequest();
            request.SetData(data);

            var response = await pusher.PushOrderCreatedAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.DataOrder.SyncState = "1";
                else
                    notification.DataOrder.SyncState = "2";

                notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _submitCaseInfoRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}