﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.Extend;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 服务工单拓展信息
    /// </summary>
    public class SubmitCaseExtendsHandler : INotificationHandler<SubmitCaseExtendsNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IReceiveCaseExtendsRepository _receiveCaseExtendsRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="receiveCaseExtendsRepository"></param>
        public SubmitCaseExtendsHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper, IReceiveCaseExtendsRepository receiveCaseExtendsRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _receiveCaseExtendsRepository = receiveCaseExtendsRepository;
        }

        /// <summary>
        /// 服务工单拓展信息
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseExtendsNotification notification, CancellationToken cancellationToken)
        {
            var strOrder = notification.DataOrder;
            if (!string.IsNullOrEmpty(strOrder))
            {
                var order = System.Text.Json.JsonSerializer.Deserialize<SubmitCaseExtendsInfoId>(strOrder);
                if (order != null && order.Info != null)
                {
                    var data = order.Info;
                    var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

                    var request = new SubmitCaseExtendsRequest();
                    request.SetData(data);

                    var response = await pusher.PushSubmitCaseExtendsAsync(request, cancellationToken);

                    //如果推送成功修改数据状态
                    if (response != null)
                    {
                        var caseInfo = await _receiveCaseExtendsRepository.GetAsync(p => p.Id == order.Id);
                        if (caseInfo != null)
                        {
                            if (response.Code == "1")
                                caseInfo.SyncState = "1";
                            else
                                caseInfo.SyncState = "2";

                            caseInfo.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                            await _receiveCaseExtendsRepository.UpdateAsync(caseInfo);
                        }
                    }
                }
            }
        }
    }
}
