﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 服务工单处理过程
    /// </summary>
    public class SubmitCaseProcessHandler : INotificationHandler<SubmitCaseProcessNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISubmitCaseProcessRepository _submitCaseProcessRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseProcessRepository"></param>
        public SubmitCaseProcessHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISubmitCaseProcessRepository submitCaseProcessRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseProcessRepository = submitCaseProcessRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseProcessNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<CaseProcess>(order);

            var data = new SubmitCaseProcessData
            {
                CaseProcesss = new List<CaseProcess>
                {
                    dataReceive
                }
            };
            var request = new SubmitCaseProcessRequest();
            request.SetData(data);

            var response = await pusher.PushSubmitCaseProcessAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.DataOrder.SyncState = "1";
                else
                    notification.DataOrder.SyncState = "2";

                notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _submitCaseProcessRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
