﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 电话记录
    /// </summary>
    public class SubmitCaseRecordHandler : INotificationHandler<SubmitCaseRecordNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISubmitCaseRecordRepository _submitCaseRecordRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseRecordRepository"></param>
        public SubmitCaseRecordHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISubmitCaseRecordRepository submitCaseRecordRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseRecordRepository = submitCaseRecordRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseRecordNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<CaseRecord>(order);

            var data = new SubmitCaseRecordData
            {
                CaseRecords = new List<CaseRecord>
                {
                    dataReceive
                }
            };
            var request = new SubmitCaseRecordRequest();
            request.SetData(data);

            var response = await pusher.PushSubmitCaseRecordAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.DataOrder.SyncState = "1";
                else
                    notification.DataOrder.SyncState = "2";

                notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _submitCaseRecordRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
