﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 
    /// </summary>
    public class SubmitCaseResultHandler : INotificationHandler<SubmitCaseResultNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISubmitCaseResultRepository _submitCaseResultRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        public SubmitCaseResultHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper, ISubmitCaseResultRepository submitCaseResultRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseResultRepository = submitCaseResultRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseResultNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<CaseResult>(order);

            var data = new SubmitCaseResultData
            {
                CaseResults = new List<CaseResult>
                {
                    dataReceive
                }
            };
            var request = new SubmitCaseResultRequest();
            request.SetData(data);

            var response = await pusher.PushSubmitCaseResultAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.DataOrder.SyncState = "1";
                else
                    notification.DataOrder.SyncState = "2";

                notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _submitCaseResultRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
