﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.HuiJu;
using Sharing.Province.Dtos.HuiJu.Send;
using Sharing.Province.HuiJu.Send;

namespace Sharing.Province.Handlers.HuiJu
{
    /// <summary>
    /// 统计数据
    /// </summary>
    public class SubmitCaseTotalHandler : INotificationHandler<SubmitCaseTotalNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISubmitCaseTotalRepository _submitCaseTotalRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="submitCaseTotalRepository"></param>
        public SubmitCaseTotalHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISubmitCaseTotalRepository submitCaseTotalRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _submitCaseTotalRepository = submitCaseTotalRepository;
        }

        /// <summary>
        /// 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SubmitCaseTotalNotification notification, CancellationToken cancellationToken)
        {
            var order = notification.DataOrder;
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<CaseTotal>(order);

            var data = new SubmitCaseTotalData
            {
                CaseTotals = new List<CaseTotal>
                {
                    dataReceive
                }
            };
            var request = new SubmitCaseTotalRequest();
            request.SetData(data);

            var response = await pusher.PushSubmitCaseTotalAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.DataOrder.SyncState = "1";
                else
                    notification.DataOrder.SyncState = "2";

                notification.DataOrder.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _submitCaseTotalRepository.UpdateAsync(notification.DataOrder);
            }
        }
    }
}
