﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.Knowledge;
using Sharing.Province.Dtos.XieTong.Knowledge;
using Sharing.Province.XieTong.Knowledge;

namespace Sharing.Province.Handlers.Knowledge
{
    /// <summary>
    /// 知识下架
    /// </summary>
    public class GetKnowledgeInfoAbandonHandler : INotificationHandler<GetKnowledgeInfoAbandonNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IGetKnowledgeInfoAbandonRepository _getKnowledgeInfoAbandonRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="getKnowledgeInfoAbandonRepository"></param>
        public GetKnowledgeInfoAbandonHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IGetKnowledgeInfoAbandonRepository getKnowledgeInfoAbandonRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _getKnowledgeInfoAbandonRepository = getKnowledgeInfoAbandonRepository;
        }

        /// <summary>
        /// 知识下架 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetKnowledgeInfoAbandonNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<GetKnowledgeInfoAbandonInfo>(notification.Data);

            var request = new GetKnowledgeInfoAbandonRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushGetKnowledgeInfoAbandonAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _getKnowledgeInfoAbandonRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
