﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.Knowledge;
using Sharing.Province.Dtos.XieTong.Knowledge;
using Sharing.Province.XieTong.Knowledge;

namespace Sharing.Province.Handlers.Knowledge
{
    /// <summary>
    /// 知识库上报
    /// </summary>
    public class GetKnowledgeInfoSendHandler : INotificationHandler<GetKnowledgeInfoSendNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IGetKnowledgeInfoSendRepository _getKnowledgeInfoSendRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="getKnowledgeInfoSendRepository"></param>
        public GetKnowledgeInfoSendHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IGetKnowledgeInfoSendRepository getKnowledgeInfoSendRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _getKnowledgeInfoSendRepository = getKnowledgeInfoSendRepository;
        }

        /// <summary>
        /// 知识库上报 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetKnowledgeInfoSendNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<KnowledgeInfoSendInfo>(notification.Data);

            var request = new GetKnowledgeInfoSendRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushGetKnowledgeInfoSendAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _getKnowledgeInfoSendRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
