﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.Knowledge;
using Sharing.Province.Dtos.XieTong.Knowledge;
using Sharing.Province.XieTong.Knowledge;

namespace Sharing.Province.Handlers.Knowledge
{
    /// <summary>
    /// 知识库变更
    /// </summary>
    public class GetKnowledgeInfoUpdateHandler : INotificationHandler<GetKnowledgeInfoUpdateNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IGetKnowledgeInfoUpdateRepository _getKnowledgeInfoUpdateRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="getKnowledgeInfoUpdateRepository"></param>
        public GetKnowledgeInfoUpdateHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IGetKnowledgeInfoUpdateRepository getKnowledgeInfoUpdateRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _getKnowledgeInfoUpdateRepository = getKnowledgeInfoUpdateRepository;
        }

        /// <summary>
        /// 知识库变更 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetKnowledgeInfoUpdateNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<GetKnowledgeInfoUpdateInfo>(notification.Data);

            var request = new GetKnowledgeInfoUpdateRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushGetKnowledgeInfoUpdateAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _getKnowledgeInfoUpdateRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
