﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 
    /// </summary>
    public class GetVisitInfoReceiveHandler : INotificationHandler<GetVisitInfoReceiveNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IGetVisitInfoReceiveRepository _getVisitInfoReceiveRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="getVisitInfoReceiveRepository"></param>
        public GetVisitInfoReceiveHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IGetVisitInfoReceiveRepository getVisitInfoReceiveRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _getVisitInfoReceiveRepository = getVisitInfoReceiveRepository;
        }

        /// <summary>
        /// 服务工单交办评价
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(GetVisitInfoReceiveNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<GetVisitInfoReceiveInfo>(notification.Data);

            var request = new GetVisitInfoReceiveRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushGetVisitInfoReceiveAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _getVisitInfoReceiveRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
