﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 实时服务上报
    /// </summary>
    public class SendRealTimeStatusHandler : INotificationHandler<SendRealTimeStatusNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISendRealTimeStatusRepository _sendRealTimeStatusRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="sendRealTimeStatusRepository"></param>
        public SendRealTimeStatusHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISendRealTimeStatusRepository sendRealTimeStatusRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _sendRealTimeStatusRepository = sendRealTimeStatusRepository;
        }

        /// <summary>
        /// 服务工单上报 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SendRealTimeStatusNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<SendRealTimeStatusInfo>(notification.Data);

            var request = new SendRealTimeStatusRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushSendRealTimeStatusAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _sendRealTimeStatusRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
