﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Receive;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 服务工单撤单
    /// </summary>
    public class SendRevokeCaseInfoHandler : INotificationHandler<SendRevokeCaseInfoNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IRevokeCaseInfoRepository _revokeCaseInfoRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="revokeCaseInfoRepository"></param>
        public SendRevokeCaseInfoHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IRevokeCaseInfoRepository revokeCaseInfoRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _revokeCaseInfoRepository = revokeCaseInfoRepository;
        }

        /// <summary>
        /// 服务工单撤单 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SendRevokeCaseInfoNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<RevokeCaseInfoInfo>(notification.Data);

            var request = new SendRevokeCaseInfoRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushRevokeCaseInfoAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _revokeCaseInfoRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
