﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 服务工单督办过程
    /// </summary>
    public class SendSuperviseProcessInfoHandler : INotificationHandler<SendSuperviseProcessInfoNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISendSuperviseProcessInfoRepository _sendSuperviseProcessInfoRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="sendSuperviseProcessInfoRepository"></param>
        public SendSuperviseProcessInfoHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISendSuperviseProcessInfoRepository sendSuperviseProcessInfoRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _sendSuperviseProcessInfoRepository = sendSuperviseProcessInfoRepository;
        }

        /// <summary>
        /// 服务工单督办过程 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SendSuperviseProcessInfoNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<SendSuperviseProcessInfoInfo>(notification.Data);

            var request = new SendSuperviseProcessInfoRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushSendSuperviseProcessInfoAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _sendSuperviseProcessInfoRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
