﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 服务工单督办结果
    /// </summary>
    public class SendSuperviseResultInfoHandler : INotificationHandler<SendSuperviseResultInfoNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISendSuperviseResultInfoRepository _sendSuperviseResultInfoRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="sendSuperviseResultInfoRepository"></param>
        public SendSuperviseResultInfoHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISendSuperviseResultInfoRepository sendSuperviseResultInfoRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _sendSuperviseResultInfoRepository = sendSuperviseResultInfoRepository;
        }

        /// <summary>
        /// 服务工单督办结果 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SendSuperviseResultInfoNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<SendSuperviseResultInfoInfo>(notification.Data);

            var request = new SendSuperviseResultInfoRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushSendSuperviseResultInfoAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _sendSuperviseResultInfoRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
