﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 上报补充诉求
    /// </summary>
    public class SupplyCaseInfoSendHandler : INotificationHandler<SupplyCaseInfoSendNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly ISupplyCaseInfoSendRepository _supplyCaseInfoSendRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="supplyCaseInfoSendRepository"></param>
        public SupplyCaseInfoSendHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , ISupplyCaseInfoSendRepository supplyCaseInfoSendRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _supplyCaseInfoSendRepository = supplyCaseInfoSendRepository;
        }

        /// <summary>
        /// 上报补充诉求 
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(SupplyCaseInfoSendNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<SupplyCaseInfoSendInfo>(notification.Data);

            var request = new SupplyCaseInfoSendRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushSupplyCaseInfoSendAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _supplyCaseInfoSendRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
