﻿using MapsterMapper;
using MediatR;
using Sharing.Notifications.XieTong;
using Sharing.Province.Dtos.XieTong.Send;
using Sharing.Province.XieTong.Send;

namespace Sharing.Province.Handlers.XieTong
{
    /// <summary>
    /// 政民互动提交公开
    /// </summary>
    public class ZMHDCaseInfoPublicHandler : INotificationHandler<ZMHDCaseInfoPublicNotification>
    {
        private readonly IChannelConfigurationManager _channelConfigurationManager;
        private readonly PusherProvider _pusherProvider;
        private readonly IMapper _mapper;
        private readonly IZMHDCaseInfoPublicRepository _zMHDCaseInfoPublicRepository;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="channelConfigurationManager"></param>
        /// <param name="pusherProvider"></param>
        /// <param name="mapper"></param>
        /// <param name="zMHDCaseInfoPublicRepository"></param>
        public ZMHDCaseInfoPublicHandler(IChannelConfigurationManager channelConfigurationManager, PusherProvider pusherProvider, IMapper mapper
            , IZMHDCaseInfoPublicRepository zMHDCaseInfoPublicRepository)
        {
            _channelConfigurationManager = channelConfigurationManager;
            _pusherProvider = pusherProvider;
            _mapper = mapper;
            _zMHDCaseInfoPublicRepository = zMHDCaseInfoPublicRepository;
        }

        /// <summary>
        /// 政民互动提交公开
        /// </summary>
        /// <param name="notification"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task Handle(ZMHDCaseInfoPublicNotification notification, CancellationToken cancellationToken = default)
        {
            var pusher = _pusherProvider.CreatePusher(_channelConfigurationManager);

            var dataReceive = _mapper.Map<ZMHDCaseInfoPublicInfo>(notification.Data);

            var request = new ZMHDCaseInfoPublicRequest();
            request.SetData(dataReceive);

            var response = await pusher.PushZMHDCaseInfoPublicAsync(request, cancellationToken);

            //如果推送成功修改数据状态
            if (response != null)
            {
                if (response.Code == "1")
                    notification.Data.SyncState = "1";
                else
                    notification.Data.SyncState = "2";

                notification.Data.ReturnResult = Newtonsoft.Json.JsonConvert.SerializeObject(response);
                await _zMHDCaseInfoPublicRepository.UpdateAsync(notification.Data);
            }
        }
    }
}
