﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net.Http.Headers;
using System.Text;
using System.Threading.Tasks;
using IdentityModel.Client;
using Microsoft.Extensions.DependencyInjection;
using Sharing.Province.Dtos;
using Sharing.Province.Extensions;
using SqlSugar;
using XF.Domain.Cache;
using XF.Domain.Exceptions;

namespace Sharing.Province
{
    public abstract class ProvinceClient //: ISingletonDependency, ISelfDependency
    {
        private static readonly string KeyToken = "KeyToken";
        private readonly IServiceScopeFactory _scopeFactory;

        public ProvinceClient(IServiceScopeFactory scopeFactory)
        {
            _scopeFactory = scopeFactory;
        }

        public async Task<TResponse?> RequestAsync<TRequest, TResponse>(
            TRequest request,
            string baseAddress,
            ConfigurationProvince configProvince,
            CancellationToken cancellationToken)
            where TRequest : IProvinceRequest, new()
        {
            using var scope = _scopeFactory.CreateScope();
            var provider = scope.ServiceProvider;
            //var channelconfigManager = provider.GetRequiredService<IChannelConfigurationManager>();
            var httpInvoker = provider.GetRequiredService<IHttpInvoker>();
            var cacheToken = provider.GetRequiredService<ITypedCache<TokenInfo>>();

            var token = cacheToken.GetOrSet(KeyToken,
                d => GetTokenAsync(cancellationToken).GetAwaiter().GetResult(),
                TimeSpan.FromMinutes(28));
            //var configProvince = channelconfigManager.GetConfigurationProvince();
            request.BuildClientInfo(configProvince.ClientId, configProvince.ClientSecret);

            //todo token失效重新获取token再次请求，返回参数缺少该状态，暂无法处理

            return await httpInvoker.RequestAsync<TRequest, TResponse>(request,
                d => d.SetHttpClient(baseAddress, token?.AccessToken ?? string.Empty),
                cancellationToken);
        }

        private async Task<TokenInfo> GetTokenAsync(CancellationToken cancellationToken)
        {
            using var scope = _scopeFactory.CreateScope();
            var provider = scope.ServiceProvider;
            var channelconfigManager = provider.GetRequiredService<IChannelConfigurationManager>();
            var httpInvoker = provider.GetRequiredService<IHttpInvoker>();

            var configProvince = channelconfigManager.GetConfigurationProvince();
            var baseAddress = configProvince.HuiJu;
            if (!baseAddress.EndsWith('/'))
                baseAddress += "/";
            var request = new ClientCredentialsTokenRequest
            {
                ClientId = configProvince.ClientId,
                ClientSecret = configProvince.ClientSecret,
                Address = $"{baseAddress}oauth2/token",
                Headers =
                {
                    Accept =
                    {
                        MediaTypeWithQualityHeaderValue.Parse("application/x-www-form-urlencoded")
                    }
                }

            };
            var tokenResponse = await httpInvoker.GetTokenAsync(request, cancellationToken);
            if (tokenResponse is null)
                throw new UserFriendlyException("获取token请求失败");
            if (tokenResponse.IsError)
                throw new UserFriendlyException("获取token请求失败");

            var tokenInfo = System.Text.Json.JsonSerializer.Deserialize<TokenRsp>(tokenResponse.Raw);
            if (tokenInfo?.TokenInfo is null)
                throw new UserFriendlyException("token解析失败");
            return tokenInfo.TokenInfo;
        }
    }
}
