﻿using System.Net.Http.Json;
using System.Security.Cryptography;
using IdentityModel.Client;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Options;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;

namespace Sharing;

public class BaseHttpInvoker : IHttpInvoker, IScopeDependency
{
    private readonly IHttpClientFactory _httpClientFactory;

    public BaseHttpInvoker(IHttpClientFactory httpClientFactory)
    {
        _httpClientFactory = httpClientFactory;
    }

    public async Task<TResponse?> RequestAsync<TRequest, TResponse>(
        TRequest request, Action<HttpClient>? setHttpClient = null, CancellationToken cancellationToken = default) 
        where TRequest : ISharingRequest, new()
    {
        var httpClient = _httpClientFactory.CreateClient();

        if (setHttpClient != null)
            setHttpClient.Invoke(httpClient);

        var url = request.GetRequestUrl();
        var method = request.GetHttpMethod();
        var rsp = string.Empty;
        if (HttpMethods.IsGet(method))
        {
            rsp = await httpClient.GetStringAsync(url, cancellationToken);

        }
        else if (HttpMethods.IsPost(method))
        {
            using var responseMessage = await httpClient.PostAsJsonAsync(url, request, cancellationToken);
            responseMessage.EnsureSuccessStatusCode();
            using var responseContent = responseMessage.Content;
            rsp = await responseContent.ReadAsStringAsync(cancellationToken);
        }
        else
        {
            throw new UserFriendlyException("暂不支持该请求方式");
        }

        return System.Text.Json.JsonSerializer.Deserialize<TResponse>(rsp);
    }

    public async Task<TokenResponse> GetTokenAsync(ClientCredentialsTokenRequest request, CancellationToken cancellationToken)
    {
        var httpClient = _httpClientFactory.CreateClient();
        return await httpClient.RequestClientCredentialsTokenAsync(request, cancellationToken);
    }
}